<?php
/**
 * Main setup.
 *
 * @package         Core_Sitemaps
 */

/**
 * Core Sitemaps Plugin.
 *
 * @package   Core_Sitemaps
 * @copyright 2019 The Core Sitemaps Contributors
 * @license   GNU General Public License, version 2
 * @link      https://github.com/GoogleChromeLabs/wp-sitemaps
 *
 * Plugin Name:       Core Sitemaps
 * Plugin URI:        https://github.com/GoogleChromeLabs/wp-sitemaps
 * Description:       A feature plugin to integrate basic XML Sitemaps in WordPress Core
 * Author:            Core Sitemaps Plugin Contributors
 * Author URI:        https://github.com/GoogleChromeLabs/wp-sitemaps/graphs/contributors
 * Text Domain:       core-sitemaps
 * Domain Path:       /languages
 * Requires at least: 5.3
 * Requires PHP:      5.6
 * Version:           0.2.0
 */

// The limit for how many sitemaps to include in an index.
const CORE_SITEMAPS_MAX_SITEMAPS    = 50000;
const CORE_SITEMAPS_REWRITE_VERSION = '2020-03-04';

// Limit the number of URLs included in as sitemap.
if ( ! defined( 'CORE_SITEMAPS_MAX_URLS' ) ) {
	define( 'CORE_SITEMAPS_MAX_URLS', 2000 );
}

require_once __DIR__ . '/inc/class-core-sitemaps.php';
require_once __DIR__ . '/inc/class-core-sitemaps-provider.php';
require_once __DIR__ . '/inc/class-core-sitemaps-index.php';
require_once __DIR__ . '/inc/class-core-sitemaps-posts.php';
require_once __DIR__ . '/inc/class-core-sitemaps-registry.php';
require_once __DIR__ . '/inc/class-core-sitemaps-renderer.php';
require_once __DIR__ . '/inc/class-core-sitemaps-stylesheet.php';
require_once __DIR__ . '/inc/class-core-sitemaps-taxonomies.php';
require_once __DIR__ . '/inc/class-core-sitemaps-users.php';
require_once __DIR__ . '/inc/functions.php';

// Boot the sitemaps system.
add_action( 'init', 'core_sitemaps_get_server' );

/**
 * Plugin activation hook.
 *
 * Adds and flushes rewrite rules.
 */
function core_sitemaps_plugin_activation() {
	$core_sitemaps = new Core_Sitemaps();
	$core_sitemaps->register_rewrites();
	flush_rewrite_rules( false );
}

register_activation_hook( __FILE__, 'core_sitemaps_plugin_activation' );

/**
 * Plugin deactivation hook.
 *
 * Adds and flushes rewrite rules.
 */
function core_sitemaps_plugin_deactivation() {
	$core_sitemaps = new Core_Sitemaps();
	$core_sitemaps->unregister_rewrites();
	flush_rewrite_rules( false );
}

register_deactivation_hook( __FILE__, 'core_sitemaps_plugin_deactivation' );
